Rachiopy
========
This python package provides a interface to the Rachio public API.

Usage
-----
```python
from rachiopy import Rachio

r = Rachio("authtoken")

r.person.info()
```

For the complete documentation visit [read the docs](https://rachiopy.readthedocs.io/en/latest/).
